@@ -3,20 +3,15 @@ mod common;
 use std::fmt::Debug;
 
 use bytes::Bytes;
-#[cfg(feature = "wrapper")]
-use common::TestGenericWrapper;
-use common::{TestResponse, TestServer};
+use common::{Middle, TestGenericWrapper, TestResponse, TestServer};
 use derive_builder::Builder;
 use httpmock::prelude::*;
-use rustify::endpoint::Endpoint;
+use rustify::{endpoint::Endpoint, errors::ClientError};
 use rustify_derive::Endpoint;
-use serde::{Deserialize, Serialize};
+use serde::{de::DeserializeOwned, Deserialize, Serialize};
 use serde_json::json;
-#[cfg(feature = "middleware")]
-use {
-    common::Middle, rustify::errors::ClientError, serde::de::DeserializeOwned,
-    serde_with::skip_serializing_none, std::marker::PhantomData,
-};
+use serde_with::skip_serializing_none;
+use std::marker::PhantomData;
 
 #[tokio::test]
 async fn test_path() {
@@ -163,7 +158,7 @@ async fn test_raw_data() {
 #[tokio::test]
 async fn test_result() {
     #[derive(Debug, Endpoint, Serialize)]
-    #[endpoint(path = "test/path", result = "TestResponse")]
+    #[endpoint(path = "test/path", response = "TestResponse")]
     struct Test {}
 
     #[derive(Deserialize)]
@@ -210,10 +205,9 @@ async fn test_builder() {
 }
 
 #[tokio::test]
-#[cfg(feature = "middleware")]
 async fn test_mutate() {
     #[derive(Debug, Endpoint, Serialize)]
-    #[endpoint(path = "test/path", result = "TestResponse")]
+    #[endpoint(path = "test/path", response = "TestResponse")]
     struct Test {}
 
     let t = TestServer::default();
@@ -232,10 +226,9 @@ async fn test_mutate() {
 }
 
 #[tokio::test]
-#[cfg(feature = "wrapper")]
 async fn test_wrapper() {
     #[derive(Debug, Endpoint, Serialize)]
-    #[endpoint(path = "test/path", result = "TestResponse")]
+    #[endpoint(path = "test/path", response = "TestResponse")]
     struct Test {}
 
     fn strip<T>(wrapper: TestGenericWrapper<T>) -> T {
@@ -257,7 +250,7 @@ async fn test_wrapper() {
 #[tokio::test]
 async fn test_raw_response() {
     #[derive(Debug, Endpoint, Serialize)]
-    #[endpoint(path = "test/path", result = "TestResponse")]
+    #[endpoint(path = "test/path", response = "TestResponse")]
     struct Test {}
     let resp_data = json!({"result": {"age": 30}});
 
@@ -275,11 +268,10 @@ async fn test_raw_response() {
 }
 
 #[tokio::test]
-#[cfg(feature = "middleware")]
 async fn test_generic() {
     #[skip_serializing_none]
     #[derive(Builder, Debug, Endpoint, Serialize)]
-    #[endpoint(path = "test/path/{self.name}", result = "TestResponse<T>")]
+    #[endpoint(path = "test/path/{self.name}", response = "TestResponse<T>")]
     #[builder(setter(into, strip_option))]
     struct Test<T: DeserializeOwned + Serialize + Debug + Send + Sync> {
         #[serde(skip)]
@@ -323,14 +315,13 @@ async fn test_generic() {
 }
 
 #[tokio::test]
-#[cfg(feature = "middleware")]
 async fn test_complex() {
     #[skip_serializing_none]
     #[derive(Builder, Debug, Default, Endpoint, Serialize)]
     #[endpoint(
         path = "test/path/{self.name}",
         method = "POST",
-        result = "TestResponse",
+        response = "TestResponse",
         builder = "true"
     )]
     #[builder(setter(into, strip_option), default)]
